![logo pykeops](http://www.kernel-operations.io/keops/_images/keops_logo.png)

**keopscore** contains the [KeOps](https://www.kernel-operations.io/) meta programming engine. Given a formula, 
it generates the c++/cuda code executed on the fly. 

# Usage 

This modules is for developers only and should be used only through 
bindings (e.g. [pykeops](https://pypi.org/project/pykeops/) or [Rkeops](https://cran.r-project.org/web/packages/rkeops/index.html))

* [Documentation](https://www.kernel-operations.io/)
* [Code](https://github.com/getkeops/keops/)

# Authors

- [Benjamin Charlier](https://imag.umontpellier.fr/~charlier/)
- [Jean Feydy](https://www.math.ens.fr/~feydy/)
- [Joan Alexis Glaunès](https://www.mi.parisdescartes.fr/~glaunes/)
